pub fn parse(source: &str) -> ParseResult<Statement>Expand description
Parse a Cypher query string into an AST.
Returns the AST (if parsing succeeded or error recovery produced a partial result) and all collected errors.
pub fn parse(source: &str) -> ParseResult<Statement>Parse a Cypher query string into an AST.
Returns the AST (if parsing succeeded or error recovery produced a partial result) and all collected errors.