pub fn ident() -> impl Parser<Token, SmolStr, Error = Simple<Token>> + CloneExpand description
Parse an identifier (unquoted, escaped, or keyword used in identifier position).
Cypher allows most keywords to be used as identifiers in non-ambiguous contexts (variable names, labels, property names, map keys, relationship types).
Uses filter_map instead of select! to avoid monomorphization bloat from 70+ arms,
which otherwise causes linker failures from excessively long symbol names.